@@ -41,19 +41,31 @@ sub main {
 	
 	$page.="<h3>Appearance Options</h3>";
 
+# Data structure key:
+#		['parameterName',			# as resolved by $params->{'parameterName'}
+#			['value-names', ...],	# one per table column
+#			['value', ...],			# as will appear in value="" field
+#			'description'],			# text description of parameter
+
 	my $boxes = [
-		['recurse',
-			['', 'Show', 'Hide'],
-			['', '1', ''],
-			'all categories and answers below current category'],
+#		['recurse',
+#			['', 'Show', 'Hide'],
+#			['', '1', ''],
+#			'all categories and answers below current category'],
 		['showModerator',
 			['', 'Show', 'Hide'],
 			['', '1', ''],
 			'name of moderator who organizes current category'],
-		['showLastModified',
-			['', 'Show', 'Hide'],
-			['', '1', ''],
-			'last modified date'],
+		($FAQ::OMatic::Config::showLastModifiedAlways||0)
+			? ['',
+				['', '', ''],
+				['', '', ''],
+				'<i>last modified date always shown</i>']
+			: ['showLastModified',
+				['', 'Show', 'Hide'],
+				['', '1', ''],
+				'last modified date']
+			,
 		['showEditCmds',
 			['', 'Show', 'Hide'],
 			['', '1', ''],
@@ -84,7 +96,8 @@ sub main {
 					."\" value=\""
 					.$setup->[2][$choice]
 					."\"";
-				if ($params->{$setup->[0]} eq $setup->[2][$choice]) {
+				my $existing = $params->{$setup->[0]} || '';
+				if ($existing eq $setup->[2][$choice]) {
 					$page.=" checked\n";
 				}
 				$page.="> "
@@ -100,7 +113,9 @@ sub main {
 		."</td></tr>\n";
 	$page.="</table></form>\n";
 
-	$page.= FAQ::OMatic::pageFooter();
+	$page.=FAQ::OMatic::Help::helpFor($params, 'Appearance Options', "\n");
+
+	$page.= FAQ::OMatic::pageFooter($params, ['help', 'faq']);
 
 	print $page;
 }
